// Open Chromium's development tools so we can see log output.
require('nw.gui').Window.get().showDevTools();

// Fix NW.js so it works with J5
nw.require("nwjs-j5-fix").fix();

// Create Johnny-Five object so we can then create a new Board object to work with.
var five = nw.require("johnny-five");
var board = new five.Board();

// Add a callback to be triggered when the board is ready.
board.on("ready", function() {

  // If we see this in the console, we know the board is ready!
  console.log("Board ready!");

  // Create a LED object (digital output #13) and make it blink every 500ms.
  var led = new five.Led(13);
  led.blink(500);

  // Create a new Piezo object to control our piezo buzzer.
  var piezo = new five.Piezo(3);

  // Create a Proximity object for our Sharp distance sensor (analog input 0).
  var proximity = new five.Proximity({
    controller: "GP2Y0A02YK0F",
    pin: "A0"
  });

  // Add a callback function to be executed whem distance data is received.
  proximity.on("data", function() {

    var minDist = 20,
        maxDist = 150,
        minValue = Math.sqrt(70),
        maxValue = Math.sqrt(1000);

    if (this.cm > minDist && this.cm < maxDist) {

      var ratio = (this.cm - minDist) / (maxDist - minDist);
      var value = (ratio * (maxValue - minValue)) + minValue;
      piezo.frequency(value * value, 1000);

      document.getElementsByTagName("h1")[0].style.opacity = ratio;

    } else {
      piezo.off();
    }

  });

});
